@@ -192,28 +192,3 @@ class Converter:
                     print(len(atoms))
             traj.extend(atoms)
         write(self.output, traj)
-
-        
-class CLI(BaseCLI):
-    def add_args(self):
-        self.parser.add_argument(
-            "inputs",
-            nargs="+",
-            metavar="input",
-            help="Input files (with extensions) to convert. Multiple inputs are concatenated into output",
-        )
-        self.parser.add_argument(
-            "output",
-            nargs=1,
-            help="Output file name to write conversion to (with extension)",
-        )
-        self.parser.add_argument("-i", "--indices", nargs=1, type=str, default=":",
-                help="Indices of input files to read. E.g., :10, -3:, :100:5")
-        # self.parser.add_argument("-n", nargs=1, type=int,
-        #        help="Max number of images to take from each db")
-        # self.parser.add_argument("-p", "--path", nargs=1, type=str, default="./data",
-        #        help="Specify path to dataset directory")
-
-    def main(self, args):
-        converter = Converter(args.inputs, args.output[0], args.indices)
-        converter.convert()
